<?php
/**
 * The header for our theme
 *
 * @subpackage Motivational Speaker
 * @since 1.0
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js no-svg">
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<?php
	if ( function_exists( 'wp_body_open' ) ) {
	    wp_body_open();
	} else {
	    do_action( 'wp_body_open' );
	}
?>
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'motivational-speaker' ); ?></a>
	
	<div id="page" class="site">
		<div id="header">
			<div class="container">
				<div class="wrap_figure">
					<div class="top_bar text-center text-lg-left text-md-left">
						<div class="container">
							<div class="row">
								<div class="col-lg-3 col-md-6 col-sm-6 align-self-center">
									<div class="logo">
								        <?php if ( has_custom_logo() ) : ?>
						            		<?php the_custom_logo(); ?>
							            <?php endif; ?>
						              	<?php $blog_info = get_bloginfo( 'name' ); ?>
							                <?php if ( ! empty( $blog_info ) ) : ?>
							                  	<?php if ( is_front_page() && is_home() ) : ?>
							                    	<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
							                  	<?php else : ?>
						                      		<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						                  		<?php endif; ?>
							                <?php endif; ?>
							                <?php
						                  		$description = get_bloginfo( 'description', 'display' );
							                  	if ( $description || is_customize_preview() ) :
							                ?>
						                  	<p class="site-description">
						                    	<?php echo esc_html($description); ?>
						                  	</p>
						              	<?php endif; ?>
								    </div>
								</div>
								<div class="col-lg-3 col-md-6 col-sm-6 align-self-center">
									<?php if( get_theme_mod('motivational_speaker_email_address_text') != '' || get_theme_mod('motivational_speaker_email_address') != '' ){ ?>
										<div class="row mailling-box">
											<div class="col-lg-2 col-md-2 align-self-center">
												<i class="fas fa-envelope"></i>
											</div>
											<div class="col-lg-10 col-md-10 align-self-center">											
												<h6 class="mb-0"><?php echo esc_html(get_theme_mod('motivational_speaker_email_address_text','')); ?></h6>
												<p class="mb-0"><?php echo esc_html(get_theme_mod('motivational_speaker_email_address','')); ?></p>
											</div>
										</div>
									<?php }?>
								</div>
								<div class="col-lg-4 col-md-6 col-sm-6 align-self-center">
									<div class="searching-box">
										<?php get_search_form(); ?>
									</div>
								</div>
								<div class="col-lg-2 col-md-6 col-sm-6 align-self-center media-box">
									<?php if( get_theme_mod('motivational_speaker_social_facebook') != '' ){ ?>
										<a href="<?php echo esc_url(get_theme_mod('motivational_speaker_social_facebook','')); ?>" class="mb-0"><i class="fab fa-facebook-f"></i></a>
									<?php }?>
									<?php if( get_theme_mod('motivational_speaker_social_twitter') != '' ){ ?>
										<a href="<?php echo esc_url(get_theme_mod('motivational_speaker_social_twitter','')); ?>" class="mb-0"><i class="fab fa-twitter"></i></a>
									<?php }?>
									<?php if( get_theme_mod('motivational_speaker_social_youtube') != '' ){ ?>
										<a href="<?php echo esc_url(get_theme_mod('motivational_speaker_social_youtube','')); ?>" class="mb-0"><i class="fab fa-youtube"></i></a>
									<?php }?>
									<?php if( get_theme_mod('motivational_speaker_social_instagram') != '' ){ ?>
										<a href="<?php echo esc_url(get_theme_mod('motivational_speaker_social_instagram','')); ?>" class="mb-0"><i class="fab fa-instagram"></i></a>
									<?php }?>
								</div>
							</div>
						</div>
					</div>
					<div class="menu_header">
						<div class="container">
							<div class="row">
								<div class="col-lg-9 col-md-4 col-sm-4 col-3 align-self-center">
									<?php if(has_nav_menu('primary')){?>
										<div class="toggle-menu gb_menu">
											<button onclick="motivational_speaker_gb_Menu_open()" class="gb_toggle p-2"><i class="fas fa-ellipsis-h"></i><p class="mb-0"><?php esc_html_e('Menu','motivational-speaker'); ?></p></button>
										</div>
									<?php }?>
					   				<?php get_template_part('template-parts/navigation/navigation'); ?>
					   			</div>
					   			<div class="col-lg-3 col-md-8 col-sm-8 col-9 align-self-center">
					   				<?php if( get_theme_mod('motivational_speaker_call_text') != '' || get_theme_mod('motivational_speaker_call_number') != '' ){ ?>
						   				<div class="row calling-box">
											<div class="col-lg-2 col-md-2 col-3 align-self-center">
												<i class="fas fa-phone"></i>
											</div>
											<div class="col-lg-10 col-md-10 col-9 align-self-center">
												<h6 class="mb-0"><?php echo esc_html(get_theme_mod('motivational_speaker_call_text','')); ?></h6>
												<p class="mb-0"><?php echo esc_html(get_theme_mod('motivational_speaker_call_number','')); ?></p>
											</div>
										</div>
									<?php }?>
					   			</div>
					   		</div>
						</div>
					</div>
				</div>
			</div>
		</div>