<?php
/**
 * Motivational Speaker: Customizer
 *
 * @subpackage Motivational Speaker
 * @since 1.0
 */

function motivational_speaker_customize_register( $wp_customize ) {

	wp_enqueue_style('customizercustom_css', esc_url( get_template_directory_uri() ). '/assets/css/customizer.css');

	// Add custom control.
  	require get_parent_theme_file_path( 'inc/customize/customize_toggle.php' );

	// Register the custom control type.
	$wp_customize->register_control_type( 'motivational_speaker_Toggle_Control' );

	$wp_customize->add_section( 'motivational_speaker_typography_settings', array(
		'title'       => __( 'Typography', 'motivational-speaker' ),
		'priority'       => 24,
	) );

	$font_choices = array(
			'' => 'Select',
			'Source Sans Pro:400,700,400italic,700italic' => 'Source Sans Pro',
			'Open Sans:400italic,700italic,400,700' => 'Open Sans',
			'Oswald:400,700' => 'Oswald',
			'Playfair Display:400,700,400italic' => 'Playfair Display',
			'Montserrat:400,700' => 'Montserrat',
			'Raleway:400,700' => 'Raleway',
			'Droid Sans:400,700' => 'Droid Sans',
			'Lato:400,700,400italic,700italic' => 'Lato',
			'Arvo:400,700,400italic,700italic' => 'Arvo',
			'Lora:400,700,400italic,700italic' => 'Lora',
			'Merriweather:400,300italic,300,400italic,700,700italic' => 'Merriweather',
			'Oxygen:400,300,700' => 'Oxygen',
			'PT Serif:400,700' => 'PT Serif',
			'PT Sans:400,700,400italic,700italic' => 'PT Sans',
			'PT Sans Narrow:400,700' => 'PT Sans Narrow',
			'Cabin:400,700,400italic' => 'Cabin',
			'Fjalla One:400' => 'Fjalla One',
			'Francois One:400' => 'Francois One',
			'Josefin Sans:400,300,600,700' => 'Josefin Sans',
			'Libre Baskerville:400,400italic,700' => 'Libre Baskerville',
			'Arimo:400,700,400italic,700italic' => 'Arimo',
			'Ubuntu:400,700,400italic,700italic' => 'Ubuntu',
			'Bitter:400,700,400italic' => 'Bitter',
			'Droid Serif:400,700,400italic,700italic' => 'Droid Serif',
			'Roboto:400,400italic,700,700italic' => 'Roboto',
			'Open Sans Condensed:700,300italic,300' => 'Open Sans Condensed',
			'Roboto Condensed:400italic,700italic,400,700' => 'Roboto Condensed',
			'Roboto Slab:400,700' => 'Roboto Slab',
			'Yanone Kaffeesatz:400,700' => 'Yanone Kaffeesatz',
			'Rokkitt:400' => 'Rokkitt',
		);


	$wp_customize->add_setting( 'motivational_speaker_headings_text', array(
		'sanitize_callback' => 'motivational_speaker_sanitize_fonts',
	));
	$wp_customize->add_control( 'motivational_speaker_headings_text', array(
		'type' => 'select',
		'description' => __('Select your suitable font for the headings.', 'motivational-speaker'),
		'section' => 'motivational_speaker_typography_settings',
		'choices' => $font_choices		
	));

	$wp_customize->add_setting( 'motivational_speaker_body_text', array(
		'sanitize_callback' => 'motivational_speaker_sanitize_fonts'
	));
	$wp_customize->add_control( 'motivational_speaker_body_text', array(
		'type' => 'select',
		'description' => __( 'Select your suitable font for the body.', 'motivational-speaker' ),
		'section' => 'motivational_speaker_typography_settings',
		'choices' => $font_choices
	) );

 	$wp_customize->add_section('motivational_speaker_pro', array(
        'title'    => __('UPGRADE MOTIVATIONAL PREMIUM', 'motivational-speaker'),
        'priority' => 1,
    ));

    $wp_customize->add_setting('motivational_speaker_pro', array(
        'default'           => null,
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control(new Motivational_Speaker_Pro_Control($wp_customize, 'motivational_speaker_pro', array(
        'label'    => __('MOTIVATIONAL SPEAKER PREMIUM', 'motivational-speaker'),
        'section'  => 'motivational_speaker_pro',
        'settings' => 'motivational_speaker_pro',
        'priority' => 1,
    )));

    // Theme General Settings
    $wp_customize->add_section('motivational_speaker_theme_settings',array(
        'title' => __('Theme General Settings', 'motivational-speaker'),
    ) );

    $wp_customize->add_setting( 'motivational_speaker_sticky_header', array(
		'default'           => false,
		'transport'         => 'refresh',
		'sanitize_callback' => 'motivational_speaker_sanitize_checkbox',
	) );
	$wp_customize->add_control( new motivational_speaker_Toggle_Control( $wp_customize, 'motivational_speaker_sticky_header', array(
		'label'       => esc_html__( 'Show Sticky Header', 'motivational-speaker' ),
		'section'     => 'motivational_speaker_theme_settings',
		'type'        => 'toggle',
		'settings'    => 'motivational_speaker_sticky_header',
	) ) );

    //theme width
	$wp_customize->add_section('motivational_speaker_theme_width_settings',array(
        'title' => __('Theme Width Option', 'motivational-speaker'),
        'priority'   => 1,
    ) );

	$wp_customize->add_setting('motivational_speaker_width_options',array(
        'default' => 'full_width',
        'sanitize_callback' => 'motivational_speaker_sanitize_choices'
	));
	$wp_customize->add_control('motivational_speaker_width_options',array(
        'type' => 'select',
        'label' => __('Theme Width Option','motivational-speaker'),
        'section' => 'motivational_speaker_theme_width_settings',
        'choices' => array(
            'full_width' => __('Fullwidth','motivational-speaker'),
            'container' => __('Container','motivational-speaker'),
            'container_fluid' => __('Container Fluid','motivational-speaker'),
        ),
	) );

	// Post Layouts
    $wp_customize->add_section('motivational_speaker_layout',array(
        'title' => __('Post Layout', 'motivational-speaker'),
        'description' => __( 'Change the post layout from below options', 'motivational-speaker' ),
        'priority' => 1
    ) );

	$wp_customize->add_setting( 'motivational_speaker_post_sidebar', array(
		'default'           => false,
		'transport'         => 'refresh',
		'sanitize_callback' => 'motivational_speaker_sanitize_checkbox',
	) );
	$wp_customize->add_control( new motivational_speaker_Toggle_Control( $wp_customize, 'motivational_speaker_post_sidebar', array(
		'label'       => esc_html__( 'Show Fullwidth', 'motivational-speaker' ),
		'section'     => 'motivational_speaker_layout',
		'type'        => 'toggle',
		'settings'    => 'motivational_speaker_post_sidebar',
	) ) );

	$wp_customize->add_setting( 'motivational_speaker_single_post_sidebar', array(
		'default'           => false,
		'transport'         => 'refresh',
		'sanitize_callback' => 'motivational_speaker_sanitize_checkbox',
	) );
	$wp_customize->add_control( new motivational_speaker_Toggle_Control( $wp_customize, 'motivational_speaker_single_post_sidebar', array(
		'label'       => esc_html__( 'Show Single Post Fullwidth', 'motivational-speaker' ),
		'section'     => 'motivational_speaker_layout',
		'type'        => 'toggle',
		'settings'    => 'motivational_speaker_single_post_sidebar',
	) ) );

    $wp_customize->add_setting('motivational_speaker_post_option',array(
		'default' => 'simple_post',
		'sanitize_callback' => 'motivational_speaker_sanitize_select'
	));
	$wp_customize->add_control('motivational_speaker_post_option',array(
		'label' => esc_html__('Select Layout','motivational-speaker'),
		'section' => 'motivational_speaker_layout',
		'setting' => 'motivational_speaker_post_option',
		'type' => 'radio',
        'choices' => array(
            'simple_post' => __('Simple Post','motivational-speaker'),
            'grid_post' => __('Grid Post','motivational-speaker'),
        ),
	));

    $wp_customize->add_setting('motivational_speaker_grid_column',array(
		'default' => '3_column',
		'sanitize_callback' => 'motivational_speaker_sanitize_select'
	));
	$wp_customize->add_control('motivational_speaker_grid_column',array(
		'label' => esc_html__('Grid Post Per Row','motivational-speaker'),
		'section' => 'motivational_speaker_layout',
		'setting' => 'motivational_speaker_grid_column',
		'type' => 'radio',
        'choices' => array(
            '1_column' => __('1','motivational-speaker'),
            '2_column' => __('2','motivational-speaker'),
            '3_column' => __('3','motivational-speaker'),
            '4_column' => __('4','motivational-speaker'),
            '5_column' => __('6','motivational-speaker'),
        ),
	));

	$wp_customize->add_setting( 'motivational_speaker_date', array(
		'default'           => true,
		'transport'         => 'refresh',
		'sanitize_callback' => 'motivational_speaker_sanitize_checkbox',
	) );
	$wp_customize->add_control( new motivational_speaker_Toggle_Control( $wp_customize, 'motivational_speaker_date', array(
		'label'       => esc_html__( 'Hide Date', 'motivational-speaker' ),
		'section'     => 'motivational_speaker_layout',
		'type'        => 'toggle',
		'settings'    => 'motivational_speaker_date',
	) ) );

	$wp_customize->add_setting( 'motivational_speaker_admin', array(
		'default'           => true,
		'transport'         => 'refresh',
		'sanitize_callback' => 'motivational_speaker_sanitize_checkbox',
	) );
	$wp_customize->add_control( new motivational_speaker_Toggle_Control( $wp_customize, 'motivational_speaker_admin', array(
		'label'       => esc_html__( 'Hide Author/Admin', 'motivational-speaker' ),
		'section'     => 'motivational_speaker_layout',
		'type'        => 'toggle',
		'settings'    => 'motivational_speaker_admin',
	) ) );

	$wp_customize->add_setting( 'motivational_speaker_comment', array(
		'default'           => true,
		'transport'         => 'refresh',
		'sanitize_callback' => 'motivational_speaker_sanitize_checkbox',
	) );
	$wp_customize->add_control( new motivational_speaker_Toggle_Control( $wp_customize, 'motivational_speaker_comment', array(
		'label'       => esc_html__( 'Hide Comment', 'motivational-speaker' ),
		'section'     => 'motivational_speaker_layout',
		'type'        => 'toggle',
		'settings'    => 'motivational_speaker_comment',
	) ) );

	// Top Header
    $wp_customize->add_section('motivational_speaker_top',array(
        'title' => __('Contact info', 'motivational-speaker'),
        'priority' => 1
    ) );

    $wp_customize->add_setting('motivational_speaker_call_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	)); 
	$wp_customize->add_control('motivational_speaker_call_text',array(
		'label' => esc_html__('Add Phone Text','motivational-speaker'),
		'section' => 'motivational_speaker_top',
		'setting' => 'motivational_speaker_call_text',
		'type'    => 'text'
	));

    $wp_customize->add_setting('motivational_speaker_call_number',array(
		'default' => '',
		'sanitize_callback' => 'motivational_speaker_sanitize_phone_number'
	)); 
	$wp_customize->add_control('motivational_speaker_call_number',array(
		'label' => esc_html__('Add Phone Number','motivational-speaker'),
		'section' => 'motivational_speaker_top',
		'setting' => 'motivational_speaker_call_number',
		'type'    => 'text'
	));

    $wp_customize->add_setting('motivational_speaker_email_address_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	)); 
	$wp_customize->add_control('motivational_speaker_email_address_text',array(
		'label' => esc_html__('Add Email Text','motivational-speaker'),
		'section' => 'motivational_speaker_top',
		'setting' => 'motivational_speaker_email_address_text',
		'type'    => 'text'
	));

    $wp_customize->add_setting('motivational_speaker_email_address',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_email'
	)); 
	$wp_customize->add_control('motivational_speaker_email_address',array(
		'label' => esc_html__('Add Email Address','motivational-speaker'),
		'section' => 'motivational_speaker_top',
		'setting' => 'motivational_speaker_email_address',
		'type'    => 'text'
	));

	// Social Media
    $wp_customize->add_section('motivational_speaker_social_media',array(
        'title' => __('Social Media', 'motivational-speaker'),
        'priority' => 1
    ) );

    $wp_customize->add_setting('motivational_speaker_social_facebook',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	)); 
	$wp_customize->add_control('motivational_speaker_social_facebook',array(
		'label' => esc_html__('Add Facebook URL','motivational-speaker'),
		'section' => 'motivational_speaker_social_media',
		'setting' => 'motivational_speaker_social_facebook',
		'type'    => 'url'
	));

    $wp_customize->add_setting('motivational_speaker_social_twitter',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	)); 
	$wp_customize->add_control('motivational_speaker_social_twitter',array(
		'label' => esc_html__('Add Twitter URL','motivational-speaker'),
		'section' => 'motivational_speaker_social_media',
		'setting' => 'motivational_speaker_social_twitter',
		'type'    => 'url'
	));

    $wp_customize->add_setting('motivational_speaker_social_youtube',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	)); 
	$wp_customize->add_control('motivational_speaker_social_youtube',array(
		'label' => esc_html__('Add Youtube URL','motivational-speaker'),
		'section' => 'motivational_speaker_social_media',
		'setting' => 'motivational_speaker_social_youtube',
		'type'    => 'url'
	));

    $wp_customize->add_setting('motivational_speaker_social_instagram',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	)); 
	$wp_customize->add_control('motivational_speaker_social_instagram',array(
		'label' => esc_html__('Add Instagram URL','motivational-speaker'),
		'section' => 'motivational_speaker_social_media',
		'setting' => 'motivational_speaker_social_instagram',
		'type'    => 'url'
	));

    //Slider
	$wp_customize->add_section( 'motivational_speaker_slider_section' , array(
    	'title'      => __( 'Slider Settings', 'motivational-speaker' ),
    	'description' => __('Slider Image Dimension ( 600px x 700px )','motivational-speaker'),
		'priority'   => 3,
	) );

	$wp_customize->add_setting( 'motivational_speaker_slider_arrows', array(
		'default'           => false,
		'transport'         => 'refresh',
		'sanitize_callback' => 'motivational_speaker_sanitize_checkbox',
	) );
	$wp_customize->add_control( new motivational_speaker_Toggle_Control( $wp_customize, 'motivational_speaker_slider_arrows', array(
		'label'       => esc_html__( 'Check to show slider', 'motivational-speaker' ),
		'section'     => 'motivational_speaker_slider_section',
		'type'        => 'toggle',
		'settings'    => 'motivational_speaker_slider_arrows',
	) ) );

	$args = array('numberposts' => -1); 
	$post_list = get_posts($args);
	$i = 0;	
	$pst_sls[]= __('Select','motivational-speaker');
	foreach ($post_list as $key => $p_post) {
		$pst_sls[$p_post->ID]=$p_post->post_title;
	}
	for ( $i = 1; $i <= 4; $i++ ) {
		$wp_customize->add_setting('motivational_speaker_post_setting'.$i,array(
			'sanitize_callback' => 'motivational_speaker_sanitize_select',
		));
		$wp_customize->add_control('motivational_speaker_post_setting'.$i,array(
			'type'    => 'select',
			'choices' => $pst_sls,
			'label' => __('Select post','motivational-speaker'),
			'section' => 'motivational_speaker_slider_section',
		));
	}
	wp_reset_postdata();

	// Latest Program
	$wp_customize->add_section( 'motivational_speaker_middle_section' , array(
		'title'      => __( 'Latest Program Settings', 'motivational-speaker' ),
		'priority'   => 6,
	) );

	$wp_customize->add_setting('motivational_speaker_program_section_title',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	)); 
	$wp_customize->add_control('motivational_speaker_program_section_title',array(
		'label' => esc_html__('Title','motivational-speaker'),
		'section' => 'motivational_speaker_middle_section',
		'setting' => 'motivational_speaker_program_section_title',
		'type'    => 'text'
	));
	
	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_post[]= 'select';
	foreach($categories as $category){
	if($i==0){
	  $default = $category->slug;
	  $i++;
	}
	$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('motivational_speaker_latest_program_setting',array(
		'default' => 'select',
		'sanitize_callback' => 'motivational_speaker_sanitize_select',
	));
	$wp_customize->add_control('motivational_speaker_latest_program_setting',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => esc_html__('Select Category to display program','motivational-speaker'),
		'section' => 'motivational_speaker_middle_section',
	));
    
	//Footer
    $wp_customize->add_section( 'motivational_speaker_footer_copyright', array(
    	'title'      => esc_html__( 'Footer Text', 'motivational-speaker' ),
    	'priority' => 6
	) );

    $wp_customize->add_setting('motivational_speaker_footer_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('motivational_speaker_footer_text',array(
		'label'	=> esc_html__('Copyright Text','motivational-speaker'),
		'section'	=> 'motivational_speaker_footer_copyright',
		'type'		=> 'text'
	));

	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'motivational_speaker_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'motivational_speaker_customize_partial_blogdescription',
	) );

	//front page
	$num_sections = apply_filters( 'motivational_speaker_front_page_sections', 4 );

	// Create a setting and control for each of the sections available in the theme.
	for ( $i = 1; $i < ( 1 + $num_sections ); $i++ ) {
		$wp_customize->add_setting( 'panel_' . $i, array(
			'default'           => false,
			'sanitize_callback' => 'motivational_speaker_sanitize_dropdown_pages',
			'transport'         => 'postMessage',
		) );

		$wp_customize->add_control( 'panel_' . $i, array(
			/* translators: %d is the front page section number */
			'label'          => sprintf( __( 'Front Page Section %d Content', 'motivational-speaker' ), $i ),
			'description'    => ( 1 !== $i ? '' : __( 'Select pages to feature in each area from the dropdowns. Add an image to a section by setting a featured image in the page editor. Empty sections will not be displayed.', 'motivational-speaker' ) ),
			'section'        => 'theme_options',
			'type'           => 'dropdown-pages',
			'allow_addition' => true,
			'active_callback' => 'motivational_speaker_is_static_front_page',
		) );

		$wp_customize->selective_refresh->add_partial( 'panel_' . $i, array(
			'selector'            => '#panel' . $i,
			'render_callback'     => 'motivational_speaker_front_page_section',
			'container_inclusive' => true,
		) );
	}
}
add_action( 'customize_register', 'motivational_speaker_customize_register' );

function motivational_speaker_customize_partial_blogname() {
	bloginfo( 'name' );
}
function motivational_speaker_customize_partial_blogdescription() {
	bloginfo( 'description' );
}
function motivational_speaker_is_static_front_page() {
	return ( is_front_page() && ! is_home() );
}
function motivational_speaker_is_view_with_layout_option() {
	return ( is_page() || ( is_archive() && ! is_active_sidebar( 'sidebar-1' ) ) );
}

define('MOTIVATIONAL_SPEAKER_PRO_LINK',__('https://www.ovationthemes.com/wordpress/motivational-speaker-wordpress-theme/','motivational-speaker'));

/* Pro control */
if (class_exists('WP_Customize_Control') && !class_exists('Motivational_Speaker_Pro_Control')):
    class Motivational_Speaker_Pro_Control extends WP_Customize_Control{

    public function render_content(){?>
        <label style="overflow: hidden; zoom: 1;">
	        <div class="col-md upsell-btn">
                <a href="<?php echo esc_url( MOTIVATIONAL_SPEAKER_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE MOTIVATIONAL PREMIUM','motivational-speaker');?> </a>
	        </div>
            <div class="col-md">
                <img class="motivational_speaker_img_responsive " src="<?php echo esc_url(get_template_directory_uri()); ?>/screenshot.png">
            </div>
	        <div class="col-md">
	            <h3 style="margin-top:10px; margin-left: 20px; text-decoration:underline; color:#333;"><?php esc_html_e('Motivational Speaker PREMIUM - Features', 'motivational-speaker'); ?></h3>
                <ul style="padding-top:10px">
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Responsive Design', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Boxed or fullwidth layout', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Shortcode Support', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Demo Importer', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Section Reordering', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Contact Page Template', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Multiple Blog Layouts', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Unlimited Color Options', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Designed with HTML5 and CSS3', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Customizable Design & Code', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Cross Browser Support', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Detailed Documentation Included', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Stylish Custom Widgets', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Patterns Background', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('WPML Compatible (Translation Ready)', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Woo-commerce Compatible', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Full Support', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('10+ Sections', 'motivational-speaker');?> </li>
                    <li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Live Customizer', 'motivational-speaker');?> </li>
                   	<li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('AMP Ready', 'motivational-speaker');?> </li>
                   	<li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Clean Code', 'motivational-speaker');?> </li>
                   	<li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('SEO Friendly', 'motivational-speaker');?> </li>
                   	<li class="upsell-motivational_speaker"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Supper Fast', 'motivational-speaker');?> </li>
                </ul>
        	</div>
		    <div class="col-md upsell-btn upsell-btn-bottom">
	            <a href="<?php echo esc_url( MOTIVATIONAL_SPEAKER_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE MOTIVATIONAL PREMIUM','motivational-speaker');?> </a>
		    </div>
        </label>
    <?php } }
endif;